/*********************************************************************

    formats/smx_dsk.h

    SVI318 disk images

*********************************************************************/

#ifndef SMX_DSK_H
#define SMX_DSK_H

#include "flopimg.h"

/**************************************************************************/

LEGACY_FLOPPY_OPTIONS_EXTERN(specimx);

#endif /* SVI_DSK_H */
